==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/server-info.cc <==
// Information about a server.
//
// $Id: server-info.cc,v 1.3 1995/11/14 06:06:43 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <iostream.h>
#include "server-info.h"

// ================================================================ 
//                    Constructors and Destructors                  


Server_info::Server_info()
    : version(0), conf_pres_conf(0), pers_pres_conf(0), motd_conf(0),
      kom_news_conf(0), motd_of_lyskom(0)
{
}
 
Server_info::Server_info(const Server_info &si)
    : version(si.version), conf_pres_conf(si.conf_pres_conf),
      pers_pres_conf(si.pers_pres_conf), motd_conf(si.motd_conf),
      kom_news_conf(si.kom_news_conf), motd_of_lyskom(si.motd_of_lyskom)
{
}


Server_info::Server_info(prot_a_LyStr &str)
    : version(str.stol()),        conf_pres_conf(str.stol()),
      pers_pres_conf(str.stol()), motd_conf(str.stol()),
      kom_news_conf(str.stol()),  motd_of_lyskom(str.stol())
{    
}


Server_info::~Server_info()
{
}


// ================================================================ 
//

const Server_info & 
Server_info::operator = (const Server_info &si)
{
    version= si.version;
    conf_pres_conf = si.conf_pres_conf;
    pers_pres_conf = si.pers_pres_conf;
    motd_conf = si.motd_conf;
    kom_news_conf = si.kom_news_conf;
    motd_of_lyskom = si.motd_of_lyskom;

    return *this;
}


//ostream &
//operator <<(ostream &, const Server_info &)
//{
//}


long
Server_info::get_version()
{
    return version;
}

Conf_no
Server_info::get_conf_pres_conf()
{
    return conf_pres_conf;
}

Conf_no
Server_info::get_pers_pres_conf()
{
    return pers_pres_conf;
}

Conf_no
Server_info::get_motd_conf()
{
    return motd_conf;
}

Conf_no
Server_info::get_kom_news_conf()
{
    return kom_news_conf;
}

Text_no
Server_info::get_motd_of_lyskom()
{
    return motd_of_lyskom;
}

==> kom%2B%2B-0.7.tar.gz: kom++-0.7/libkom++/server-info.cc <==
// Information about a server.
//
// $Id: server-info.cc,v 1.4 1996/08/26 08:44:37 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <iostream.h>
#include "server-info.h"

// ================================================================ 
//                    Constructors and Destructors                  


Server_info::Server_info()
    : version(0), conf_pres_conf(0), pers_pres_conf(0), motd_conf(0),
      kom_news_conf(0), motd_of_lyskom(0)
{
}
 
Server_info::Server_info(const Server_info &si)
    : version(si.version), conf_pres_conf(si.conf_pres_conf),
      pers_pres_conf(si.pers_pres_conf), motd_conf(si.motd_conf),
      kom_news_conf(si.kom_news_conf), motd_of_lyskom(si.motd_of_lyskom)
{
}


Server_info::Server_info(prot_a_LyStr &str)
    : version(str.stol()),        conf_pres_conf(str.stol()),
      pers_pres_conf(str.stol()), motd_conf(str.stol()),
      kom_news_conf(str.stol()),  motd_of_lyskom(str.stol())
{    
}


Server_info::~Server_info()
{
}


// ================================================================ 
//

const Server_info & 
Server_info::operator = (const Server_info &si)
{
    version= si.version;
    conf_pres_conf = si.conf_pres_conf;
    pers_pres_conf = si.pers_pres_conf;
    motd_conf = si.motd_conf;
    kom_news_conf = si.kom_news_conf;
    motd_of_lyskom = si.motd_of_lyskom;

    return *this;
}


//ostream &
//operator <<(ostream &, const Server_info &)
//{
//}


long
Server_info::get_version() const
{
    return version;
}

Conf_no
Server_info::get_conf_pres_conf() const
{
    return conf_pres_conf;
}

Conf_no
Server_info::get_pers_pres_conf() const
{
    return pers_pres_conf;
}

Conf_no
Server_info::get_motd_conf() const
{
    return motd_conf;
}

Conf_no
Server_info::get_kom_news_conf() const
{
    return kom_news_conf;
}

Text_no
Server_info::get_motd_of_lyskom() const
{
    return motd_of_lyskom;
}
